@@ -300,7 +300,7 @@ class WOLens(Lens, OpticalElementDecorator):
             raise Exception("Python code autogenerated only if created with WOLens.create_from_keywords()")
 
         txt = ""
-        txt += "\nfrom orangecontrib.esrf.wofry.util.lens import WOLens"
+        txt += "\nfrom wofryimpl.beamline.optical_elements.refractors.lens import WOLens"
         txt += "\n"
         txt += "\noptical_element = WOLens.create_from_keywords("
         txt += "\n    name='%s',"                    % self._keywords_at_creation["name"]
@@ -605,7 +605,7 @@ class WOLens1D(Lens, OpticalElementDecorator):
             raise Exception("Python code autogenerated only if created with WOLens.create_from_keywords()")
 
         txt = ""
-        txt += "\nfrom orangecontrib.esrf.wofry.util.lens import WOLens1D"
+        txt += "\nfrom wofryimpl.beamline.optical_elements.refractors.lens import WOLens1D"
         txt += "\n"
         txt += "\noptical_element = WOLens1D.create_from_keywords("
         txt += "\n    name='%s'," % self.get_name()
